GPayProvider class

Inheritance

Constructors

GPayProvider({required String secretKey, required String appKey})

Properties

appKey String
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
paymentUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
fetchTransaction(String orderNumber) Future<Map<String, dynamic>>
Fetches transaction details.
initiatePayment(double amount, BuildContext context) Future<void>
Initiates a payment and displays a WebView modal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited